%%
%% %CopyrightBegin%
%%
%% SPDX-License-Identifier: Apache-2.0 AND LicenseRef-scancode-wxwindows-free-doc-3
%%
%% Copyright Ericsson AB 2008-2025. All Rights Reserved.
%%
%% Licensed under the Apache License, Version 2.0 (the "License");
%% you may not use this file except in compliance with the License.
%% You may obtain a copy of the License at
%%
%%     http://www.apache.org/licenses/LICENSE-2.0
%%
%% Unless required by applicable law or agreed to in writing, software
%% distributed under the License is distributed on an "AS IS" BASIS,
%% WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
%% See the License for the specific language governing permissions and
%% limitations under the License.
%%
%% For documentation, wxWindow Free Documentation License, Version 3 applies.
%% wxWindows Free Documentation Licence, Version 3, as follows.
%% ===============================================
%%
%% Everyone is permitted to copy and distribute verbatim copies
%% of this licence document, but changing it is not allowed.
%%
%%                  WXWINDOWS FREE DOCUMENTATION LICENCE
%%    TERMS AND CONDITIONS FOR COPYING, DISTRIBUTION AND MODIFICATION
%%
%% 1. Permission is granted to make and distribute verbatim copies of this
%% manual or piece of documentation provided any copyright notice and this
%% permission notice are preserved on all copies.
%%
%% 2. Permission is granted to process this file or document through a
%% document processing system and, at your option and the option of any third
%% party, print the results, provided a printed document carries a copying
%% permission notice identical to this one.
%%
%% 3. Permission is granted to copy and distribute modified versions of this
%% manual or piece of documentation under the conditions for verbatim copying,
%% provided also that any sections describing licensing conditions for this
%% manual, such as, in particular, the GNU General Public Licence, the GNU
%% Library General Public Licence, and any wxWindows Licence are included
%% exactly as in the original, and provided that the entire resulting derived
%% work is distributed under the terms of a permission notice identical to
%% this one.
%%
%% 4. Permission is granted to copy and distribute translations of this manual
%% or piece of documentation into another language, under the above conditions
%% for modified versions, except that sections related to licensing, including
%% this paragraph, may also be included in translations approved by the
%% copyright holders of the respective licence documents in addition to the
%% original English.
%%
%% %CopyrightEnd%
%% This file is generated DO NOT EDIT

-module(wxCalendarCtrl).
-moduledoc """
The calendar control allows the user to pick a date.

The user can move the current selection using the keyboard and select the date
(generating `EVT_CALENDAR` event) by pressing `<Return>` or double clicking it.

Generic calendar has advanced possibilities for the customization of its display,
described below. If you want to use these possibilities on every platform, use
wxGenericCalendarCtrl instead of `m:wxCalendarCtrl`.

All global settings (such as colours and fonts used) can, of course, be changed. But
also, the display style for each day in the month can be set independently using `m:wxCalendarDateAttr`
class.

An item without custom attributes is drawn with the default colours and font and without
border, but setting custom attributes with `setAttr/3` allows modifying its appearance. Just create a
custom attribute object and set it for the day you want to be displayed specially (note
that the control will take ownership of the pointer, i.e. it will delete it itself). A day
may be marked as being a holiday, even if it is not recognized as one by `wx_datetime()` using the `wxCalendarDateAttr:setHoliday/2` method.

As the attributes are specified for each day, they may change when the month is changed,
so you will often want to update them in `EVT_CALENDAR_PAGE_CHANGED` event handler.

If neither the `wxCAL_SUNDAY_FIRST` or `wxCAL_MONDAY_FIRST` style is given, the first day
of the week is determined from operating system's settings, if possible. The native wxGTK
calendar chooses the first weekday based on locale, and these styles have no effect on it.

## Styles

This class supports the following styles:

* wxCAL_SUNDAY_FIRST: Show Sunday as the first day in the week (not in wxGTK)

* wxCAL_MONDAY_FIRST: Show Monday as the first day in the week (not in wxGTK)

* wxCAL_SHOW_HOLIDAYS: Highlight holidays in the calendar (only generic)

* wxCAL_NO_YEAR_CHANGE: Disable the year changing (deprecated, only generic)

* wxCAL_NO_MONTH_CHANGE: Disable the month (and, implicitly, the year) changing

* wxCAL_SHOW_SURROUNDING_WEEKS: Show the neighbouring weeks in the previous and next months
(only generic, always on for the native controls)

* wxCAL_SEQUENTIAL_MONTH_SELECTION: Use alternative, more compact, style for the month and
year selection controls. (only generic)

* wxCAL_SHOW_WEEK_NUMBERS: Show week numbers on the left side of the calendar. (not in
generic)

See:
* [Examples](https://docs.wxwidgets.org/3.2/page_samples.html#page_samples_calendar)

* `m:wxCalendarDateAttr`

* `m:wxCalendarEvent`

* `m:wxDatePickerCtrl`

This class is derived, and can use functions, from:

* `m:wxControl`

* `m:wxWindow`

* `m:wxEvtHandler`

wxWidgets docs: [wxCalendarCtrl](https://docs.wxwidgets.org/3.2/classwx_calendar_ctrl.html)

## Events

Event types emitted from this class:

* [`calendar_sel_changed`](`m:wxCalendarEvent`)

* [`calendar_weekday_clicked`](`m:wxCalendarEvent`)
""".
-include("wxe.hrl").
-export([create/3,create/4,destroy/1,enableHolidayDisplay/1,enableHolidayDisplay/2,
  enableMonthChange/1,enableMonthChange/2,enableYearChange/1,enableYearChange/2,
  getAttr/2,getDate/1,getHeaderColourBg/1,getHeaderColourFg/1,getHighlightColourBg/1,
  getHighlightColourFg/1,getHolidayColourBg/1,getHolidayColourFg/1,
  hitTest/2,new/0,new/2,new/3,resetAttr/2,setAttr/3,setDate/2,setHeaderColours/3,
  setHighlightColours/3,setHoliday/2,setHolidayColours/3]).

%% inherited exports
-export([cacheBestSize/2,canSetTransparent/1,captureMouse/1,center/1,center/2,
  centerOnParent/1,centerOnParent/2,centre/1,centre/2,centreOnParent/1,
  centreOnParent/2,clearBackground/1,clientToScreen/2,clientToScreen/3,
  close/1,close/2,connect/2,connect/3,convertDialogToPixels/2,convertPixelsToDialog/2,
  destroyChildren/1,disable/1,disconnect/1,disconnect/2,disconnect/3,
  dragAcceptFiles/2,enable/1,enable/2,findWindow/2,fit/1,fitInside/1,
  freeze/1,getAcceleratorTable/1,getBackgroundColour/1,getBackgroundStyle/1,
  getBestSize/1,getCaret/1,getCharHeight/1,getCharWidth/1,getChildren/1,
  getClientSize/1,getContainingSizer/1,getContentScaleFactor/1,getCursor/1,
  getDPI/1,getDPIScaleFactor/1,getDropTarget/1,getExtraStyle/1,getFont/1,
  getForegroundColour/1,getGrandParent/1,getHandle/1,getHelpText/1,
  getId/1,getLabel/1,getMaxSize/1,getMinSize/1,getName/1,getParent/1,
  getPosition/1,getRect/1,getScreenPosition/1,getScreenRect/1,getScrollPos/2,
  getScrollRange/2,getScrollThumb/2,getSize/1,getSizer/1,getTextExtent/2,
  getTextExtent/3,getThemeEnabled/1,getToolTip/1,getUpdateRegion/1,
  getVirtualSize/1,getWindowStyleFlag/1,getWindowVariant/1,hasCapture/1,
  hasScrollbar/2,hasTransparentBackground/1,hide/1,inheritAttributes/1,
  initDialog/1,invalidateBestSize/1,isDoubleBuffered/1,isEnabled/1,
  isExposed/2,isExposed/3,isExposed/5,isFrozen/1,isRetained/1,isShown/1,
  isShownOnScreen/1,isTopLevel/1,layout/1,lineDown/1,lineUp/1,lower/1,
  move/2,move/3,move/4,moveAfterInTabOrder/2,moveBeforeInTabOrder/2,
  navigate/1,navigate/2,pageDown/1,pageUp/1,parent_class/1,popupMenu/2,
  popupMenu/3,popupMenu/4,raise/1,refresh/1,refresh/2,refreshRect/2,refreshRect/3,
  releaseMouse/1,removeChild/2,reparent/2,screenToClient/1,screenToClient/2,
  scrollLines/2,scrollPages/2,scrollWindow/3,scrollWindow/4,setAcceleratorTable/2,
  setAutoLayout/2,setBackgroundColour/2,setBackgroundStyle/2,setCaret/2,
  setClientSize/2,setClientSize/3,setContainingSizer/2,setCursor/2,
  setDoubleBuffered/2,setDropTarget/2,setExtraStyle/2,setFocus/1,setFocusFromKbd/1,
  setFont/2,setForegroundColour/2,setHelpText/2,setId/2,setLabel/2,setMaxSize/2,
  setMinSize/2,setName/2,setOwnBackgroundColour/2,setOwnFont/2,setOwnForegroundColour/2,
  setPalette/2,setScrollPos/3,setScrollPos/4,setScrollbar/5,setScrollbar/6,
  setSize/2,setSize/3,setSize/5,setSize/6,setSizeHints/2,setSizeHints/3,
  setSizeHints/4,setSizer/2,setSizer/3,setSizerAndFit/2,setSizerAndFit/3,
  setThemeEnabled/2,setToolTip/2,setTransparent/2,setVirtualSize/2,
  setVirtualSize/3,setWindowStyle/2,setWindowStyleFlag/2,setWindowVariant/2,
  shouldInheritColours/1,show/1,show/2,thaw/1,transferDataFromWindow/1,
  transferDataToWindow/1,update/1,updateWindowUI/1,updateWindowUI/2,
  validate/1,warpPointer/3]).

-type wxCalendarCtrl() :: wx:wx_object().
-export_type([wxCalendarCtrl/0]).
-deprecated([{enableYearChange,1,"not available in wxWidgets-2.9 and later"},
             
  {enableYearChange,2,"not available in wxWidgets-2.9 and later"}]).

-doc false.
parent_class(wxControl) -> true;
parent_class(wxWindow) -> true;
parent_class(wxEvtHandler) -> true;
parent_class(_Class) -> erlang:error({badtype, ?MODULE}).

-doc "Default constructor.".
-spec new() -> wxCalendarCtrl().
new() ->
  wxe_util:queue_cmd(?get_env(), ?wxCalendarCtrl_new_0),
  wxe_util:rec(?wxCalendarCtrl_new_0).

-doc(#{equiv => new(Parent,Id, [])}).
-spec new(Parent, Id) -> wxCalendarCtrl() when
	Parent::wxWindow:wxWindow(), Id::integer().

new(Parent,Id)
 when is_record(Parent, wx_ref),is_integer(Id) ->
  new(Parent,Id, []).

-doc "Does the same as `create/4` method.".
-spec new(Parent, Id, [Option]) -> wxCalendarCtrl() when
	Parent::wxWindow:wxWindow(), Id::integer(),
	Option :: {'date', wx:wx_datetime()}
		 | {'pos', {X::integer(), Y::integer()}}
		 | {'size', {W::integer(), H::integer()}}
		 | {'style', integer()}.
new(#wx_ref{type=ParentT}=Parent,Id, Options)
 when is_integer(Id),is_list(Options) ->
  ?CLASS(ParentT,wxWindow),
  MOpts = fun({date, {{DateY,DateMo,DateD},{DateH,DateMi,DateS}}}) -> {date,{DateD,DateMo,DateY,DateH,DateMi,DateS}};
          ({pos, {_posX,_posY}} = Arg) -> Arg;
          ({size, {_sizeW,_sizeH}} = Arg) -> Arg;
          ({style, _style} = Arg) -> Arg;
          (BadOpt) -> erlang:error({badoption, BadOpt}) end,
  Opts = lists:map(MOpts, Options),
  wxe_util:queue_cmd(Parent,Id, Opts,?get_env(),?wxCalendarCtrl_new_3),
  wxe_util:rec(?wxCalendarCtrl_new_3).

-doc(#{equiv => create(This,Parent,Id, [])}).
-spec create(This, Parent, Id) -> boolean() when
	This::wxCalendarCtrl(), Parent::wxWindow:wxWindow(), Id::integer().

create(This,Parent,Id)
 when is_record(This, wx_ref),is_record(Parent, wx_ref),is_integer(Id) ->
  create(This,Parent,Id, []).

-doc """
Creates the control.

See `wxWindow:new/3` for the meaning of the parameters and the control overview for the possible styles.
""".
-spec create(This, Parent, Id, [Option]) -> boolean() when
	This::wxCalendarCtrl(), Parent::wxWindow:wxWindow(), Id::integer(),
	Option :: {'date', wx:wx_datetime()}
		 | {'pos', {X::integer(), Y::integer()}}
		 | {'size', {W::integer(), H::integer()}}
		 | {'style', integer()}.
create(#wx_ref{type=ThisT}=This,#wx_ref{type=ParentT}=Parent,Id, Options)
 when is_integer(Id),is_list(Options) ->
  ?CLASS(ThisT,wxCalendarCtrl),
  ?CLASS(ParentT,wxWindow),
  MOpts = fun({date, {{DateY,DateMo,DateD},{DateH,DateMi,DateS}}}) -> {date,{DateD,DateMo,DateY,DateH,DateMi,DateS}};
          ({pos, {_posX,_posY}} = Arg) -> Arg;
          ({size, {_sizeW,_sizeH}} = Arg) -> Arg;
          ({style, _style} = Arg) -> Arg;
          (BadOpt) -> erlang:error({badoption, BadOpt}) end,
  Opts = lists:map(MOpts, Options),
  wxe_util:queue_cmd(This,Parent,Id, Opts,?get_env(),?wxCalendarCtrl_Create),
  wxe_util:rec(?wxCalendarCtrl_Create).

-doc """
Sets the current date.

The `date` parameter must be valid and in the currently valid range as set by `SetDateRange()`
(not implemented in wx), otherwise the current date is not changed and the function
returns false and, additionally, triggers an assertion failure if the date is invalid.
""".
-spec setDate(This, Date) -> boolean() when
	This::wxCalendarCtrl(), Date::wx:wx_datetime().
setDate(#wx_ref{type=ThisT}=This,{{DateY,DateMo,DateD},{DateH,DateMi,DateS}})
 when is_integer(DateD),is_integer(DateMo),is_integer(DateY),is_integer(DateH),is_integer(DateMi),is_integer(DateS) ->
  ?CLASS(ThisT,wxCalendarCtrl),
  wxe_util:queue_cmd(This,{DateD,DateMo,DateY,DateH,DateMi,DateS},?get_env(),?wxCalendarCtrl_SetDate),
  wxe_util:rec(?wxCalendarCtrl_SetDate).

-doc "Gets the currently selected date.".
-spec getDate(This) -> wx:wx_datetime() when
	This::wxCalendarCtrl().
getDate(#wx_ref{type=ThisT}=This) ->
  ?CLASS(ThisT,wxCalendarCtrl),
  wxe_util:queue_cmd(This,?get_env(),?wxCalendarCtrl_GetDate),
  wxe_util:rec(?wxCalendarCtrl_GetDate).

-doc(#{equiv => enableYearChange(This, [])}).
-spec enableYearChange(This) -> 'ok' when
	This::wxCalendarCtrl().

enableYearChange(This)
 when is_record(This, wx_ref) ->
  enableYearChange(This, []).

-doc """
Deprecated:

This function should be used instead of changing `wxCAL_NO_YEAR_CHANGE` style bit
directly. It allows or disallows the user to change the year interactively. Only in
generic `m:wxCalendarCtrl`.
""".
-spec enableYearChange(This, [Option]) -> 'ok' when
	This::wxCalendarCtrl(),
	Option :: {'enable', boolean()}.
enableYearChange(#wx_ref{type=ThisT}=This, Options)
 when is_list(Options) ->
  ?CLASS(ThisT,wxCalendarCtrl),
  MOpts = fun({enable, _enable} = Arg) -> Arg;
          (BadOpt) -> erlang:error({badoption, BadOpt}) end,
  Opts = lists:map(MOpts, Options),
  wxe_util:queue_cmd(This, Opts,?get_env(),?wxCalendarCtrl_EnableYearChange).

-doc(#{equiv => enableMonthChange(This, [])}).
-spec enableMonthChange(This) -> boolean() when
	This::wxCalendarCtrl().

enableMonthChange(This)
 when is_record(This, wx_ref) ->
  enableMonthChange(This, []).

-doc """
This function should be used instead of changing `wxCAL\_NO\_MONTH\_CHANGE` style bit.

It allows or disallows the user to change the month interactively. Note that if the month
cannot be changed, the year cannot be changed neither.

Return: true if the value of this option really changed or false if it was already set to
the requested value.
""".
-spec enableMonthChange(This, [Option]) -> boolean() when
	This::wxCalendarCtrl(),
	Option :: {'enable', boolean()}.
enableMonthChange(#wx_ref{type=ThisT}=This, Options)
 when is_list(Options) ->
  ?CLASS(ThisT,wxCalendarCtrl),
  MOpts = fun({enable, _enable} = Arg) -> Arg;
          (BadOpt) -> erlang:error({badoption, BadOpt}) end,
  Opts = lists:map(MOpts, Options),
  wxe_util:queue_cmd(This, Opts,?get_env(),?wxCalendarCtrl_EnableMonthChange),
  wxe_util:rec(?wxCalendarCtrl_EnableMonthChange).

-doc(#{equiv => enableHolidayDisplay(This, [])}).
-spec enableHolidayDisplay(This) -> 'ok' when
	This::wxCalendarCtrl().

enableHolidayDisplay(This)
 when is_record(This, wx_ref) ->
  enableHolidayDisplay(This, []).

-doc """
This function should be used instead of changing `wxCAL\_SHOW\_HOLIDAYS` style bit
directly.

It enables or disables the special highlighting of the holidays.
""".
-spec enableHolidayDisplay(This, [Option]) -> 'ok' when
	This::wxCalendarCtrl(),
	Option :: {'display', boolean()}.
enableHolidayDisplay(#wx_ref{type=ThisT}=This, Options)
 when is_list(Options) ->
  ?CLASS(ThisT,wxCalendarCtrl),
  MOpts = fun({display, _display} = Arg) -> Arg;
          (BadOpt) -> erlang:error({badoption, BadOpt}) end,
  Opts = lists:map(MOpts, Options),
  wxe_util:queue_cmd(This, Opts,?get_env(),?wxCalendarCtrl_EnableHolidayDisplay).

-doc """
Set the colours used for painting the weekdays at the top of the control.

This method is currently only implemented in generic `m:wxCalendarCtrl` and does nothing
in the native versions.
""".
-spec setHeaderColours(This, ColFg, ColBg) -> 'ok' when
	This::wxCalendarCtrl(), ColFg::wx:wx_colour(), ColBg::wx:wx_colour().
setHeaderColours(#wx_ref{type=ThisT}=This,ColFg,ColBg)
 when ?is_colordata(ColFg),?is_colordata(ColBg) ->
  ?CLASS(ThisT,wxCalendarCtrl),
  wxe_util:queue_cmd(This,wxe_util:color(ColFg),wxe_util:color(ColBg),?get_env(),?wxCalendarCtrl_SetHeaderColours).

-doc """
Gets the foreground colour of the header part of the calendar window.

This method is currently only implemented in generic `m:wxCalendarCtrl` and always
returns `wxNullColour` in the native versions.

See: `setHeaderColours/3`
""".
-spec getHeaderColourFg(This) -> wx:wx_colour4() when
	This::wxCalendarCtrl().
getHeaderColourFg(#wx_ref{type=ThisT}=This) ->
  ?CLASS(ThisT,wxCalendarCtrl),
  wxe_util:queue_cmd(This,?get_env(),?wxCalendarCtrl_GetHeaderColourFg),
  wxe_util:rec(?wxCalendarCtrl_GetHeaderColourFg).

-doc """
Gets the background colour of the header part of the calendar window.

This method is currently only implemented in generic `m:wxCalendarCtrl` and always
returns `wxNullColour` in the native versions.

See: `setHeaderColours/3`
""".
-spec getHeaderColourBg(This) -> wx:wx_colour4() when
	This::wxCalendarCtrl().
getHeaderColourBg(#wx_ref{type=ThisT}=This) ->
  ?CLASS(ThisT,wxCalendarCtrl),
  wxe_util:queue_cmd(This,?get_env(),?wxCalendarCtrl_GetHeaderColourBg),
  wxe_util:rec(?wxCalendarCtrl_GetHeaderColourBg).

-doc """
Set the colours to be used for highlighting the currently selected date.

This method is currently only implemented in generic `m:wxCalendarCtrl` and does nothing
in the native versions.
""".
-spec setHighlightColours(This, ColFg, ColBg) -> 'ok' when
	This::wxCalendarCtrl(), ColFg::wx:wx_colour(), ColBg::wx:wx_colour().
setHighlightColours(#wx_ref{type=ThisT}=This,ColFg,ColBg)
 when ?is_colordata(ColFg),?is_colordata(ColBg) ->
  ?CLASS(ThisT,wxCalendarCtrl),
  wxe_util:queue_cmd(This,wxe_util:color(ColFg),wxe_util:color(ColBg),?get_env(),?wxCalendarCtrl_SetHighlightColours).

-doc """
Gets the foreground highlight colour.

Only in generic `m:wxCalendarCtrl`.

This method is currently only implemented in generic `m:wxCalendarCtrl` and always
returns `wxNullColour` in the native versions.

See: `setHighlightColours/3`
""".
-spec getHighlightColourFg(This) -> wx:wx_colour4() when
	This::wxCalendarCtrl().
getHighlightColourFg(#wx_ref{type=ThisT}=This) ->
  ?CLASS(ThisT,wxCalendarCtrl),
  wxe_util:queue_cmd(This,?get_env(),?wxCalendarCtrl_GetHighlightColourFg),
  wxe_util:rec(?wxCalendarCtrl_GetHighlightColourFg).

-doc """
Gets the background highlight colour.

Only in generic `m:wxCalendarCtrl`.

This method is currently only implemented in generic `m:wxCalendarCtrl` and always
returns `wxNullColour` in the native versions.

See: `setHighlightColours/3`
""".
-spec getHighlightColourBg(This) -> wx:wx_colour4() when
	This::wxCalendarCtrl().
getHighlightColourBg(#wx_ref{type=ThisT}=This) ->
  ?CLASS(ThisT,wxCalendarCtrl),
  wxe_util:queue_cmd(This,?get_env(),?wxCalendarCtrl_GetHighlightColourBg),
  wxe_util:rec(?wxCalendarCtrl_GetHighlightColourBg).

-doc """
Sets the colours to be used for the holidays highlighting.

This method is only implemented in the generic version of the control and does nothing in
the native ones. It should also only be called if the window style includes `wxCAL_SHOW_HOLIDAYS`
flag or `enableHolidayDisplay/2` had been called.
""".
-spec setHolidayColours(This, ColFg, ColBg) -> 'ok' when
	This::wxCalendarCtrl(), ColFg::wx:wx_colour(), ColBg::wx:wx_colour().
setHolidayColours(#wx_ref{type=ThisT}=This,ColFg,ColBg)
 when ?is_colordata(ColFg),?is_colordata(ColBg) ->
  ?CLASS(ThisT,wxCalendarCtrl),
  wxe_util:queue_cmd(This,wxe_util:color(ColFg),wxe_util:color(ColBg),?get_env(),?wxCalendarCtrl_SetHolidayColours).

-doc """
Return the foreground colour currently used for holiday highlighting.

Only useful with generic `m:wxCalendarCtrl` as native versions currently don't support
holidays display at all and always return `wxNullColour`.

See: `setHolidayColours/3`
""".
-spec getHolidayColourFg(This) -> wx:wx_colour4() when
	This::wxCalendarCtrl().
getHolidayColourFg(#wx_ref{type=ThisT}=This) ->
  ?CLASS(ThisT,wxCalendarCtrl),
  wxe_util:queue_cmd(This,?get_env(),?wxCalendarCtrl_GetHolidayColourFg),
  wxe_util:rec(?wxCalendarCtrl_GetHolidayColourFg).

-doc """
Return the background colour currently used for holiday highlighting.

Only useful with generic `m:wxCalendarCtrl` as native versions currently don't support
holidays display at all and always return `wxNullColour`.

See: `setHolidayColours/3`
""".
-spec getHolidayColourBg(This) -> wx:wx_colour4() when
	This::wxCalendarCtrl().
getHolidayColourBg(#wx_ref{type=ThisT}=This) ->
  ?CLASS(ThisT,wxCalendarCtrl),
  wxe_util:queue_cmd(This,?get_env(),?wxCalendarCtrl_GetHolidayColourBg),
  wxe_util:rec(?wxCalendarCtrl_GetHolidayColourBg).

-doc """
Returns the attribute for the given date (should be in the range 1...31).

The returned pointer may be NULL. Only in generic `m:wxCalendarCtrl`.
""".
-spec getAttr(This, Day) -> wxCalendarDateAttr:wxCalendarDateAttr() when
	This::wxCalendarCtrl(), Day::integer().
getAttr(#wx_ref{type=ThisT}=This,Day)
 when is_integer(Day) ->
  ?CLASS(ThisT,wxCalendarCtrl),
  wxe_util:queue_cmd(This,Day,?get_env(),?wxCalendarCtrl_GetAttr),
  wxe_util:rec(?wxCalendarCtrl_GetAttr).

-doc """
Associates the attribute with the specified date (in the range 1...31).

If the pointer is NULL, the items attribute is cleared. Only in generic `m:wxCalendarCtrl`.
""".
-spec setAttr(This, Day, Attr) -> 'ok' when
	This::wxCalendarCtrl(), Day::integer(), Attr::wxCalendarDateAttr:wxCalendarDateAttr().
setAttr(#wx_ref{type=ThisT}=This,Day,#wx_ref{type=AttrT}=Attr)
 when is_integer(Day) ->
  ?CLASS(ThisT,wxCalendarCtrl),
  ?CLASS(AttrT,wxCalendarDateAttr),
  wxe_util:queue_cmd(This,Day,Attr,?get_env(),?wxCalendarCtrl_SetAttr).

-doc """
Marks the specified day as being a holiday in the current month.

This method is only implemented in the generic version of the control and does nothing in
the native ones.
""".
-spec setHoliday(This, Day) -> 'ok' when
	This::wxCalendarCtrl(), Day::integer().
setHoliday(#wx_ref{type=ThisT}=This,Day)
 when is_integer(Day) ->
  ?CLASS(ThisT,wxCalendarCtrl),
  wxe_util:queue_cmd(This,Day,?get_env(),?wxCalendarCtrl_SetHoliday).

-doc """
Clears any attributes associated with the given day (in the range 1...31).

Only in generic `m:wxCalendarCtrl`.
""".
-spec resetAttr(This, Day) -> 'ok' when
	This::wxCalendarCtrl(), Day::integer().
resetAttr(#wx_ref{type=ThisT}=This,Day)
 when is_integer(Day) ->
  ?CLASS(ThisT,wxCalendarCtrl),
  wxe_util:queue_cmd(This,Day,?get_env(),?wxCalendarCtrl_ResetAttr).

-doc """
Returns one of wxCalendarHitTestResult constants and fills either `date` or `wd` pointer
with the corresponding value depending on the hit test code.

Not implemented in wxGTK currently.
""".
%%  Wd = ?wxDateTime_Sun | ?wxDateTime_Mon | ?wxDateTime_Tue | ?wxDateTime_Wed | ?wxDateTime_Thu | ?wxDateTime_Fri | ?wxDateTime_Sat | ?wxDateTime_Inv_WeekDay
%%  Res = ?wxCAL_HITTEST_NOWHERE | ?wxCAL_HITTEST_HEADER | ?wxCAL_HITTEST_DAY | ?wxCAL_HITTEST_INCMONTH | ?wxCAL_HITTEST_DECMONTH | ?wxCAL_HITTEST_SURROUNDING_WEEK | ?wxCAL_HITTEST_WEEK
-spec hitTest(This, Pos) -> Result when
	Result ::{Res ::wx:wx_enum(), Date::wx:wx_datetime(), Wd::wx:wx_enum()},
	This::wxCalendarCtrl(), Pos::{X::integer(), Y::integer()}.
hitTest(#wx_ref{type=ThisT}=This,{PosX,PosY} = Pos)
 when is_integer(PosX),is_integer(PosY) ->
  ?CLASS(ThisT,wxCalendarCtrl),
  wxe_util:queue_cmd(This,Pos,?get_env(),?wxCalendarCtrl_HitTest),
  wxe_util:rec(?wxCalendarCtrl_HitTest).

-doc "Destroys the object".
-spec destroy(This::wxCalendarCtrl()) -> 'ok'.
destroy(Obj=#wx_ref{type=Type}) ->
  ?CLASS(Type,wxCalendarCtrl),
  wxe_util:queue_cmd(Obj, ?get_env(), ?DESTROY_OBJECT),
  ok.
 %% From wxControl
-doc false.
setLabel(This,Label) -> wxControl:setLabel(This,Label).
-doc false.
getLabel(This) -> wxControl:getLabel(This).
 %% From wxWindow
-doc false.
getDPI(This) -> wxWindow:getDPI(This).
-doc false.
getContentScaleFactor(This) -> wxWindow:getContentScaleFactor(This).
-doc false.
setDoubleBuffered(This,On) -> wxWindow:setDoubleBuffered(This,On).
-doc false.
isDoubleBuffered(This) -> wxWindow:isDoubleBuffered(This).
-doc false.
canSetTransparent(This) -> wxWindow:canSetTransparent(This).
-doc false.
setTransparent(This,Alpha) -> wxWindow:setTransparent(This,Alpha).
-doc false.
warpPointer(This,X,Y) -> wxWindow:warpPointer(This,X,Y).
-doc false.
validate(This) -> wxWindow:validate(This).
-doc false.
updateWindowUI(This, Options) -> wxWindow:updateWindowUI(This, Options).
-doc false.
updateWindowUI(This) -> wxWindow:updateWindowUI(This).
-doc false.
update(This) -> wxWindow:update(This).
-doc false.
transferDataToWindow(This) -> wxWindow:transferDataToWindow(This).
-doc false.
transferDataFromWindow(This) -> wxWindow:transferDataFromWindow(This).
-doc false.
thaw(This) -> wxWindow:thaw(This).
-doc false.
show(This, Options) -> wxWindow:show(This, Options).
-doc false.
show(This) -> wxWindow:show(This).
-doc false.
shouldInheritColours(This) -> wxWindow:shouldInheritColours(This).
-doc false.
setWindowVariant(This,Variant) -> wxWindow:setWindowVariant(This,Variant).
-doc false.
setWindowStyleFlag(This,Style) -> wxWindow:setWindowStyleFlag(This,Style).
-doc false.
setWindowStyle(This,Style) -> wxWindow:setWindowStyle(This,Style).
-doc false.
setVirtualSize(This,Width,Height) -> wxWindow:setVirtualSize(This,Width,Height).
-doc false.
setVirtualSize(This,Size) -> wxWindow:setVirtualSize(This,Size).
-doc false.
setToolTip(This,TipString) -> wxWindow:setToolTip(This,TipString).
-doc false.
setThemeEnabled(This,Enable) -> wxWindow:setThemeEnabled(This,Enable).
-doc false.
setSizerAndFit(This,Sizer, Options) -> wxWindow:setSizerAndFit(This,Sizer, Options).
-doc false.
setSizerAndFit(This,Sizer) -> wxWindow:setSizerAndFit(This,Sizer).
-doc false.
setSizer(This,Sizer, Options) -> wxWindow:setSizer(This,Sizer, Options).
-doc false.
setSizer(This,Sizer) -> wxWindow:setSizer(This,Sizer).
-doc false.
setSizeHints(This,MinW,MinH, Options) -> wxWindow:setSizeHints(This,MinW,MinH, Options).
-doc false.
setSizeHints(This,MinW,MinH) -> wxWindow:setSizeHints(This,MinW,MinH).
-doc false.
setSizeHints(This,MinSize) -> wxWindow:setSizeHints(This,MinSize).
-doc false.
setSize(This,X,Y,Width,Height, Options) -> wxWindow:setSize(This,X,Y,Width,Height, Options).
-doc false.
setSize(This,X,Y,Width,Height) -> wxWindow:setSize(This,X,Y,Width,Height).
-doc false.
setSize(This,Width,Height) -> wxWindow:setSize(This,Width,Height).
-doc false.
setSize(This,Rect) -> wxWindow:setSize(This,Rect).
-doc false.
setScrollPos(This,Orientation,Pos, Options) -> wxWindow:setScrollPos(This,Orientation,Pos, Options).
-doc false.
setScrollPos(This,Orientation,Pos) -> wxWindow:setScrollPos(This,Orientation,Pos).
-doc false.
setScrollbar(This,Orientation,Position,ThumbSize,Range, Options) -> wxWindow:setScrollbar(This,Orientation,Position,ThumbSize,Range, Options).
-doc false.
setScrollbar(This,Orientation,Position,ThumbSize,Range) -> wxWindow:setScrollbar(This,Orientation,Position,ThumbSize,Range).
-doc false.
setPalette(This,Pal) -> wxWindow:setPalette(This,Pal).
-doc false.
setName(This,Name) -> wxWindow:setName(This,Name).
-doc false.
setId(This,Winid) -> wxWindow:setId(This,Winid).
-doc false.
setHelpText(This,HelpText) -> wxWindow:setHelpText(This,HelpText).
-doc false.
setForegroundColour(This,Colour) -> wxWindow:setForegroundColour(This,Colour).
-doc false.
setFont(This,Font) -> wxWindow:setFont(This,Font).
-doc false.
setFocusFromKbd(This) -> wxWindow:setFocusFromKbd(This).
-doc false.
setFocus(This) -> wxWindow:setFocus(This).
-doc false.
setExtraStyle(This,ExStyle) -> wxWindow:setExtraStyle(This,ExStyle).
-doc false.
setDropTarget(This,Target) -> wxWindow:setDropTarget(This,Target).
-doc false.
setOwnForegroundColour(This,Colour) -> wxWindow:setOwnForegroundColour(This,Colour).
-doc false.
setOwnFont(This,Font) -> wxWindow:setOwnFont(This,Font).
-doc false.
setOwnBackgroundColour(This,Colour) -> wxWindow:setOwnBackgroundColour(This,Colour).
-doc false.
setMinSize(This,Size) -> wxWindow:setMinSize(This,Size).
-doc false.
setMaxSize(This,Size) -> wxWindow:setMaxSize(This,Size).
-doc false.
setCursor(This,Cursor) -> wxWindow:setCursor(This,Cursor).
-doc false.
setContainingSizer(This,Sizer) -> wxWindow:setContainingSizer(This,Sizer).
-doc false.
setClientSize(This,Width,Height) -> wxWindow:setClientSize(This,Width,Height).
-doc false.
setClientSize(This,Size) -> wxWindow:setClientSize(This,Size).
-doc false.
setCaret(This,Caret) -> wxWindow:setCaret(This,Caret).
-doc false.
setBackgroundStyle(This,Style) -> wxWindow:setBackgroundStyle(This,Style).
-doc false.
setBackgroundColour(This,Colour) -> wxWindow:setBackgroundColour(This,Colour).
-doc false.
setAutoLayout(This,AutoLayout) -> wxWindow:setAutoLayout(This,AutoLayout).
-doc false.
setAcceleratorTable(This,Accel) -> wxWindow:setAcceleratorTable(This,Accel).
-doc false.
scrollWindow(This,Dx,Dy, Options) -> wxWindow:scrollWindow(This,Dx,Dy, Options).
-doc false.
scrollWindow(This,Dx,Dy) -> wxWindow:scrollWindow(This,Dx,Dy).
-doc false.
scrollPages(This,Pages) -> wxWindow:scrollPages(This,Pages).
-doc false.
scrollLines(This,Lines) -> wxWindow:scrollLines(This,Lines).
-doc false.
screenToClient(This,Pt) -> wxWindow:screenToClient(This,Pt).
-doc false.
screenToClient(This) -> wxWindow:screenToClient(This).
-doc false.
reparent(This,NewParent) -> wxWindow:reparent(This,NewParent).
-doc false.
removeChild(This,Child) -> wxWindow:removeChild(This,Child).
-doc false.
releaseMouse(This) -> wxWindow:releaseMouse(This).
-doc false.
refreshRect(This,Rect, Options) -> wxWindow:refreshRect(This,Rect, Options).
-doc false.
refreshRect(This,Rect) -> wxWindow:refreshRect(This,Rect).
-doc false.
refresh(This, Options) -> wxWindow:refresh(This, Options).
-doc false.
refresh(This) -> wxWindow:refresh(This).
-doc false.
raise(This) -> wxWindow:raise(This).
-doc false.
popupMenu(This,Menu,X,Y) -> wxWindow:popupMenu(This,Menu,X,Y).
-doc false.
popupMenu(This,Menu, Options) -> wxWindow:popupMenu(This,Menu, Options).
-doc false.
popupMenu(This,Menu) -> wxWindow:popupMenu(This,Menu).
-doc false.
pageUp(This) -> wxWindow:pageUp(This).
-doc false.
pageDown(This) -> wxWindow:pageDown(This).
-doc false.
navigate(This, Options) -> wxWindow:navigate(This, Options).
-doc false.
navigate(This) -> wxWindow:navigate(This).
-doc false.
moveBeforeInTabOrder(This,Win) -> wxWindow:moveBeforeInTabOrder(This,Win).
-doc false.
moveAfterInTabOrder(This,Win) -> wxWindow:moveAfterInTabOrder(This,Win).
-doc false.
move(This,X,Y, Options) -> wxWindow:move(This,X,Y, Options).
-doc false.
move(This,X,Y) -> wxWindow:move(This,X,Y).
-doc false.
move(This,Pt) -> wxWindow:move(This,Pt).
-doc false.
lower(This) -> wxWindow:lower(This).
-doc false.
lineUp(This) -> wxWindow:lineUp(This).
-doc false.
lineDown(This) -> wxWindow:lineDown(This).
-doc false.
layout(This) -> wxWindow:layout(This).
-doc false.
isShownOnScreen(This) -> wxWindow:isShownOnScreen(This).
-doc false.
isTopLevel(This) -> wxWindow:isTopLevel(This).
-doc false.
isShown(This) -> wxWindow:isShown(This).
-doc false.
isRetained(This) -> wxWindow:isRetained(This).
-doc false.
isExposed(This,X,Y,W,H) -> wxWindow:isExposed(This,X,Y,W,H).
-doc false.
isExposed(This,X,Y) -> wxWindow:isExposed(This,X,Y).
-doc false.
isExposed(This,Pt) -> wxWindow:isExposed(This,Pt).
-doc false.
isEnabled(This) -> wxWindow:isEnabled(This).
-doc false.
isFrozen(This) -> wxWindow:isFrozen(This).
-doc false.
invalidateBestSize(This) -> wxWindow:invalidateBestSize(This).
-doc false.
initDialog(This) -> wxWindow:initDialog(This).
-doc false.
inheritAttributes(This) -> wxWindow:inheritAttributes(This).
-doc false.
hide(This) -> wxWindow:hide(This).
-doc false.
hasTransparentBackground(This) -> wxWindow:hasTransparentBackground(This).
-doc false.
hasScrollbar(This,Orient) -> wxWindow:hasScrollbar(This,Orient).
-doc false.
hasCapture(This) -> wxWindow:hasCapture(This).
-doc false.
getWindowVariant(This) -> wxWindow:getWindowVariant(This).
-doc false.
getWindowStyleFlag(This) -> wxWindow:getWindowStyleFlag(This).
-doc false.
getVirtualSize(This) -> wxWindow:getVirtualSize(This).
-doc false.
getUpdateRegion(This) -> wxWindow:getUpdateRegion(This).
-doc false.
getToolTip(This) -> wxWindow:getToolTip(This).
-doc false.
getThemeEnabled(This) -> wxWindow:getThemeEnabled(This).
-doc false.
getTextExtent(This,String, Options) -> wxWindow:getTextExtent(This,String, Options).
-doc false.
getTextExtent(This,String) -> wxWindow:getTextExtent(This,String).
-doc false.
getSizer(This) -> wxWindow:getSizer(This).
-doc false.
getSize(This) -> wxWindow:getSize(This).
-doc false.
getScrollThumb(This,Orientation) -> wxWindow:getScrollThumb(This,Orientation).
-doc false.
getScrollRange(This,Orientation) -> wxWindow:getScrollRange(This,Orientation).
-doc false.
getScrollPos(This,Orientation) -> wxWindow:getScrollPos(This,Orientation).
-doc false.
getScreenRect(This) -> wxWindow:getScreenRect(This).
-doc false.
getScreenPosition(This) -> wxWindow:getScreenPosition(This).
-doc false.
getRect(This) -> wxWindow:getRect(This).
-doc false.
getPosition(This) -> wxWindow:getPosition(This).
-doc false.
getParent(This) -> wxWindow:getParent(This).
-doc false.
getName(This) -> wxWindow:getName(This).
-doc false.
getMinSize(This) -> wxWindow:getMinSize(This).
-doc false.
getMaxSize(This) -> wxWindow:getMaxSize(This).
-doc false.
getId(This) -> wxWindow:getId(This).
-doc false.
getHelpText(This) -> wxWindow:getHelpText(This).
-doc false.
getHandle(This) -> wxWindow:getHandle(This).
-doc false.
getGrandParent(This) -> wxWindow:getGrandParent(This).
-doc false.
getForegroundColour(This) -> wxWindow:getForegroundColour(This).
-doc false.
getFont(This) -> wxWindow:getFont(This).
-doc false.
getExtraStyle(This) -> wxWindow:getExtraStyle(This).
-doc false.
getDPIScaleFactor(This) -> wxWindow:getDPIScaleFactor(This).
-doc false.
getDropTarget(This) -> wxWindow:getDropTarget(This).
-doc false.
getCursor(This) -> wxWindow:getCursor(This).
-doc false.
getContainingSizer(This) -> wxWindow:getContainingSizer(This).
-doc false.
getClientSize(This) -> wxWindow:getClientSize(This).
-doc false.
getChildren(This) -> wxWindow:getChildren(This).
-doc false.
getCharWidth(This) -> wxWindow:getCharWidth(This).
-doc false.
getCharHeight(This) -> wxWindow:getCharHeight(This).
-doc false.
getCaret(This) -> wxWindow:getCaret(This).
-doc false.
getBestSize(This) -> wxWindow:getBestSize(This).
-doc false.
getBackgroundStyle(This) -> wxWindow:getBackgroundStyle(This).
-doc false.
getBackgroundColour(This) -> wxWindow:getBackgroundColour(This).
-doc false.
getAcceleratorTable(This) -> wxWindow:getAcceleratorTable(This).
-doc false.
freeze(This) -> wxWindow:freeze(This).
-doc false.
fitInside(This) -> wxWindow:fitInside(This).
-doc false.
fit(This) -> wxWindow:fit(This).
-doc false.
findWindow(This,Id) -> wxWindow:findWindow(This,Id).
-doc false.
enable(This, Options) -> wxWindow:enable(This, Options).
-doc false.
enable(This) -> wxWindow:enable(This).
-doc false.
dragAcceptFiles(This,Accept) -> wxWindow:dragAcceptFiles(This,Accept).
-doc false.
disable(This) -> wxWindow:disable(This).
-doc false.
destroyChildren(This) -> wxWindow:destroyChildren(This).
-doc false.
convertPixelsToDialog(This,Sz) -> wxWindow:convertPixelsToDialog(This,Sz).
-doc false.
convertDialogToPixels(This,Sz) -> wxWindow:convertDialogToPixels(This,Sz).
-doc false.
close(This, Options) -> wxWindow:close(This, Options).
-doc false.
close(This) -> wxWindow:close(This).
-doc false.
clientToScreen(This,X,Y) -> wxWindow:clientToScreen(This,X,Y).
-doc false.
clientToScreen(This,Pt) -> wxWindow:clientToScreen(This,Pt).
-doc false.
clearBackground(This) -> wxWindow:clearBackground(This).
-doc false.
centreOnParent(This, Options) -> wxWindow:centreOnParent(This, Options).
-doc false.
centerOnParent(This, Options) -> wxWindow:centerOnParent(This, Options).
-doc false.
centreOnParent(This) -> wxWindow:centreOnParent(This).
-doc false.
centerOnParent(This) -> wxWindow:centerOnParent(This).
-doc false.
centre(This, Options) -> wxWindow:centre(This, Options).
-doc false.
center(This, Options) -> wxWindow:center(This, Options).
-doc false.
centre(This) -> wxWindow:centre(This).
-doc false.
center(This) -> wxWindow:center(This).
-doc false.
captureMouse(This) -> wxWindow:captureMouse(This).
-doc false.
cacheBestSize(This,Size) -> wxWindow:cacheBestSize(This,Size).
 %% From wxEvtHandler
-doc false.
disconnect(This,EventType, Options) -> wxEvtHandler:disconnect(This,EventType, Options).
-doc false.
disconnect(This,EventType) -> wxEvtHandler:disconnect(This,EventType).
-doc false.
disconnect(This) -> wxEvtHandler:disconnect(This).
-doc false.
connect(This,EventType, Options) -> wxEvtHandler:connect(This,EventType, Options).
-doc false.
connect(This,EventType) -> wxEvtHandler:connect(This,EventType).
